Package: VFP
Version: 1.4.4
Date: 2025-04-08
Title: Variance Function Program
Author: Andre Schuetzenmeister [cre, aut],
  Florian Dufey [aut],
  Andrea Geistanger [ctb]
Maintainer: Andre Schuetzenmeister <andre.schuetzenmeister@roche.com>
Authors@R: c(
		    person(given="Andre", family="Schuetzenmeister", email="andre.schuetzenmeister@roche.com", role = c("cre", "aut")),
			person(given="Florian", family="Dufey", email="florian.dufey@roche.com", role = c("aut")),
			person(given="Andrea", family="Geistanger", email="andrea.geistanger@roche.com", role = c("ctb"))
		    )
Depends: R (>= 3.5.0), gnm
Imports: VCA, MASS, utils, stats, graphics, grDevices, methods
Suggests: RUnit, knitr, rmarkdown, prettydoc
Description: 
  Variance function estimation for models proposed by W. Sadler in his variance function program 
  ('VFP', www.aacb.asn.au/AACB/Resources/Variance-Function-Program). Here, the idea is
  to fit multiple variance functions to a data set and consequently assess which function reflects
  the relationship 'Var ~ Mean' best. For 'in-vitro diagnostic' ('IVD') assays modeling this relationship
  is of great importance when individual test-results are used for defining follow-up treatment of patients.  
License: GPL (>= 2)
VignetteBuilder: knitr, rmarkdown
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2025-04-08 11:17:03 UTC; schueta6
Repository: CRAN
Date/Publication: 2025-04-08 12:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 11:02:18 UTC; unix
