### Generics and functions defined in this package

# predict.VFP is required

export(
	"as_rgb",
	"fit_vfp",
	"fit.vfp",
	"print.VFP",
	"summary.VFP",
	"plot.VFP",
	"predict.VFP",
	"predict_mean",
	"predictMean",
	"get_mat",
	"getMat.VCA",
	"coef.VFP",
	"legend_rm",
	"powfun2simple",
	"powfun3",
	"powfun3simple",
	"powfun4",
	"powfun4simple",
	"powfun5",
	"powfun5simple",
	"powfun6",
	"powfun6simple",
	"powfun7",
	"powfun7simple",
	"powfun8",
	"powfun8simple",
	"powfun9simple",
	"condition_handler",
	"derive_cx",
	"deriveCx",
	"precision_plot",
	"precisionPlot",
	"fit_ep17",
	"fit.EP17",
	"predict_model_ep17",
	"add_grid",
	"addGrid",
	"signif2",
	"Signif",
	"legend_rm",
	"legend.rm",
	"get_mon",
	"get_model",
	"residuals.VFP"
)

### Packages which are imported (appearing in the Description->Imports enumeration)

import( 
	"graphics",
	"grDevices",
	"stats",
	"methods",
	"gnm"
)

#importFrom("gnm", "gnm")
importFrom("MASS", "gamma.dispersion")
importFrom("utils", "capture.output")
importFrom("utils", "tail")
importFrom("VCA", "stepwiseVCA")
importFrom("VCA", "getIP.remlVCA")

### exported classes
#
#exportClasses( 	"VFP"
#		)

S3method(print, VFP)
S3method(summary, VFP)
S3method(predict, VFP)
S3method(plot, VFP)
S3method(coef, VFP)
S3method(residuals, VFP)